﻿using ProjectAirBomber.Entities;
namespace ProjectAirBomber.Drawnings;

// <summary>
/// Расширение для класса EntityBomber
/// </summary>
public static class ExtentionDrawningBomber
{
    /// <summary>
    /// Разделитель для записи информации по объекту в файл
    /// </summary>
    private static readonly string _separatorForObject = ":";

    /// <summary>
    /// Создание объекта из строки
    /// </summary>
    /// <param name="info">Строка с данными для создания объекта</param>
    /// <returns>Объект</returns>
    public static DrawningBomber? CreateDrawningBomber(this string info)
    {
        string[] strs = info.Split(_separatorForObject);
        EntityBomber? bomber = EntityAirBomber.CreateEntityAirBomber(strs);
        if (bomber != null)
        {
            return new DrawningAirBomber((EntityAirBomber)bomber);
        }

        bomber = EntityBomber.CreateEntityBomber(strs);
        if (bomber != null)
        {
            return new DrawningBomber(bomber);
        }

        return null;
    }

    /// <summary>
    /// Получение данных для сохранения в файл
    /// </summary>
    /// <param name="drawningBomber">Сохраняемый объект</param>
    /// <returns>Строка с данными по объекту</returns>
    public static string GetDataForSave(this DrawningBomber drawningBomber)
    {
        string[]? array = drawningBomber?.EntityBomber?.GetStringRepresentation();

        if (array == null)
        {
            return string.Empty;
        }

        return string.Join(_separatorForObject, array);
    }
}