﻿using System.Net.Sockets;

namespace ProjectAirBomber.Entities;

/// <summary>
/// Класс-сущность "Бомбардировщик"
/// </summary>
public class EntityAirBomber : EntityBomber
{
    /// <summary>
    /// Дополнительный цвет (для опциональных элементов)
    /// </summary>
    public Color AdditionalColor { get; private set; }
    public void SetAdditionalColor(Color color)
    {
        AdditionalColor = color;
    }

    /// <summary>
    /// Признак (опция) наличия дополнительных топливных баков
    /// </summary>
    public bool FuelTanks { get; private set; }

    /// <summary>
    /// Признак (опция) наличия бомб
    /// </summary>
    public bool Bombs { get; private set; }

    /// <summary>
    /// Инициализация полей объекта-класса бомбардировщика
    /// </summary>
    /// <param name="speed">Скорость</param>
    /// <param name="weight">Вес бомбардировщика</param>
    /// <param name="bodyColor">Основной цвет</param>
    /// <param name="additionalColor">Дополнительный цвет</param>
    /// <param name="fuelTanks">Признак наличия дополнительных топливных баков</param>
    /// <param name="bombs">Признак наличия бомб</param>
    public EntityAirBomber(int speed, double weight, Color bodyColor, Color additionalColor, bool fuelTanks, bool bombs): base(speed, weight, bodyColor)
    {
        AdditionalColor = additionalColor;
        FuelTanks = fuelTanks;
        Bombs = bombs;
    }

    /// <summary>
    /// Получение строк со значениями свойств продвинутого объекта класса-сущности
    /// </summary>
    /// <returns></returns>
    public override string[] GetStringRepresentation()
    {
        return new[] { nameof(EntityAirBomber), Speed.ToString(), Weight.ToString(), BodyColor.Name, AdditionalColor.Name,
                        FuelTanks.ToString(), Bombs.ToString()};
    }

    /// <summary>
    /// Создание продвинутого объекта из массива строк
    /// </summary>
    /// <param name="strs"></param>
    /// <returns></returns>
    public static EntityAirBomber? CreateEntityAirBomber(string[] strs)
    {
        if (strs.Length != 7 || strs[0] != nameof(EntityAirBomber))
        {
            return null;
        }
        return new EntityAirBomber(Convert.ToInt32(strs[1]), Convert.ToDouble(strs[2]), Color.FromName(strs[3]),
                                    Color.FromName(strs[4]), Convert.ToBoolean(strs[5]), Convert.ToBoolean(strs[6]));
    }
}