﻿using ProjectAirBomber.Drawnings;
using ProjectAirBomber.Entities;

namespace ProjectAirBomber;

/// <summary>
/// Форма конфигурации объекта
/// </summary>
public partial class FormBomberConfig : Form
{
    /// <summary>
    /// Объект - прорисовка военного самолёта
    /// </summary>
    private DrawningBomber? _bomber;

    /// <summary>
	/// Событие для передачи объекта
	/// </summary>
	private event Action<DrawningBomber>? _bomberDelegate;

    /// <summary>
    /// Конструктор
    /// </summary>
    public FormBomberConfig()
    {
        InitializeComponent();

        panelRed.MouseDown += Panel_MouseDown;
        panelGreen.MouseDown += Panel_MouseDown;
        panelBlue.MouseDown += Panel_MouseDown;
        panelYellow.MouseDown += Panel_MouseDown;
        panelWhite.MouseDown += Panel_MouseDown;
        panelGray.MouseDown += Panel_MouseDown;
        panelBlack.MouseDown += Panel_MouseDown;
        panelPurple.MouseDown += Panel_MouseDown;

        buttonCancel.Click += (sender, e) => Close();

    }

    /// <summary>
	/// Привязка внешнего метода к событию
	/// </summary>
	/// <param name="bomberDelegate"></param>
	public void AddEvent(Action<DrawningBomber> bomberDelegate)
    {
        _bomberDelegate += bomberDelegate;
    }

    /// <summary>
	/// Прорисовка объекта
	/// </summary>
    private void DrawObject()
    {
        Bitmap bmp = new(pictureBoxObject.Width, pictureBoxObject.Height);
        Graphics gr = Graphics.FromImage(bmp);
        _bomber?.SetPictureSize(pictureBoxObject.Width, pictureBoxObject.Height);
        _bomber?.SetPosition(15, 15);
        _bomber?.DrawTransport(gr);
        pictureBoxObject.Image = bmp;
    }

    /// <summary>
	/// Передаем информацию при нажатии на Label
	/// </summary>
	/// <param name="sender"></param>
	/// <param name="e"></param>
	private void LabelObject_MouseDown(object sender, MouseEventArgs e)
    {
        (sender as Label)?.DoDragDrop((sender as Label)?.Name ?? string.Empty, DragDropEffects.Move | DragDropEffects.Copy);
    }

    /// <summary>
	/// Проверка получаемой информации (ее типа на соответствие требуемому)
	/// </summary>
	/// <param name="sender"></param>
	/// <param name="e"></param>
	private void PanelObject_DragEnter(object sender, DragEventArgs e)
    {
        e.Effect = e.Data?.GetDataPresent(DataFormats.Text) ?? false ? DragDropEffects.Copy : DragDropEffects.None;
    }

    /// <summary>
    /// Действия при приеме перетаскиваемой информации
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void PanelObject_DragDrop(object sender, DragEventArgs e)
    {
        switch (e.Data?.GetData(DataFormats.Text)?.ToString())
        {
            case "labelSimpleObject":
                _bomber = new DrawningBomber((int)numericUpDownSpeed.Value, (double)numericUpDownWeight.Value, Color.White);
                break;
            case "labelModifiedObject":
                _bomber = new DrawningAirBomber((int)numericUpDownSpeed.Value, (double)numericUpDownWeight.Value, Color.White,
                    Color.Black, checkBoxFuelTanks.Checked, checkBoxBombs.Checked);
                break;
        }

        DrawObject();
    }

    /// <summary>
    /// Передаем информацию при нажатии на Panel
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void Panel_MouseDown(object? sender, MouseEventArgs e)
    {
        (sender as Control)?.DoDragDrop((sender as Control)?.BackColor!, DragDropEffects.Move | DragDropEffects.Copy);
    }
    private void LabelBodyColor_DragDrop(object sender, DragEventArgs e)
    {
        if (_bomber == null) return;
        _bomber.EntityBomber?.SetBodyColor((Color)e.Data.GetData(typeof(Color)));
        DrawObject();
    }
    private void LabelBodyColor_DragEnter(object sender, DragEventArgs e)
    {
        if (_bomber != null && e.Data.GetDataPresent(typeof(Color))) e.Effect = DragDropEffects.Copy;
        else e.Effect = DragDropEffects.None;
    }
    private void LabelAdditionalColor_DragDrop(object sender, DragEventArgs e)
    {
        if (_bomber != null && _bomber.EntityBomber is EntityAirBomber _airbomber)
            _airbomber.SetAdditionalColor((Color)e.Data.GetData(typeof(Color)));
        DrawObject();
    }
    private void LabelAdditionalColor_DragEnter(object sender, DragEventArgs e)
    {
        if (_bomber != null && e.Data.GetDataPresent(typeof(Color)) && _bomber.EntityBomber is EntityAirBomber) e.Effect = DragDropEffects.Copy;
        else e.Effect = DragDropEffects.None;
    }

    /// <summary>
    /// Передача объекта
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void buttonAdd_Click(object sender, EventArgs e)
    {
        if (_bomber != null)
        {
            _bomberDelegate?.Invoke(_bomber);
            Close();
        }
    }


}